# New Assets

All assets used by the Space Robotics Bench are separated into the [`srb_assets`](https://github.com/AndrejOrsula/srb_assets) repository to encourage their reuse. Both static assets (datasets) and procedural pipelines in Blender are supported.

- [Procedural Assets with Blender](./procgen.md)
